Skip to contents

Mixed Weibull distribution using the mixed copula estimator

Usage

cdfwei_MixedC(
  x,
  y,
  para.x,
  para.y,
  plot = FALSE,
  x1,
  CopFamily = "gumbelCopula",
  hyearstart = 4,
  seas2start = 11,
  ...
)

Arguments

x

Vector of quantiles. Default is AM.

y

Vector of quantiles. Default is AM.

para.x

Numeric vector containing the parameters of the distribution.

para.y

Numeric vector containing the parameters of the distribution.

plot

Logical indicating if the function shall be added to a plot.

x1

An object of class lfobj containing a daily time series. Which is a special data.frame format with columns 'day', 'month', 'year', 'flow', 'hyear' and possibly 'baseflow'.

CopFamily

Defines copula family. Currently the gumbelCopula and the indepCopula families are implemented.

hyearstart

Integer between 1 and 12, indicating the start of the hydrological year. Default is 4 (April) as start of the summer season.

seas2start

Integer between 1 and 12, indicating the start of the second season. Default is 11 (November) as start of the winter season.

...

Additional arguments.

Value

Vector of probabilities. Either by mixed probability estimator of Laaha (2023a), or by mixed copula estimator of Laaha (2023b).