Skip to contents

Mixed frequency analysis of low flows using mixed distribution and mixed copula estimators

Usage

weiMixT(x1, sortx = FALSE, T = c(100, 50, 20))

Arguments

x1

An object of class lfobj containing a daily time series. Which is a special data.frame format with columns 'day', 'month', 'year', 'flow', 'hyear' and possibly 'baseflow'.

sortx

Logical indicating if the values of x1 shall be sorted in increasing order. Default is FALSE.

T

A vector of return periods of ´design events´ for which improved estimates shall be calculated. Default is 100, 50 and 20 year events.

Value

The output is a list with following main elements: $sample is a data.frame containing event characteristics of annual low flow events. $To_events is a data.frame containing the nominal and improved probability p. and return period T. estimates of ´design events´. Further, flow characteristics including the circular seasonality index SI, the seasonality ration SR. the Spearman rank correlation of summer and winter series Rho together with its sigificantce value Rho_p-value, and the mixture rate mixture_rate.