Mixed probability estimators for minima
Usage
pobs_mixed_FUN(AM = AM, AMs = AMs, AMw = AMw, plot = FALSE, plotC = FALSE, ...)
Arguments
- AM
Annual minima series.
- AMs
Summer minima series.
- AMw
Winter minima series.
- plot
Logical indicating if the edf from the mixed distribution estimator shall be added to a plot.
- plotC
Logical indicating if the edf from the mixed copula estimator shall be added to a plot.
- ...
Additional arguments.
Value
List of folowing elements: AM annual minima series, pMix empirical probabilities by mixed probability estimator of Laaha (2023a), pMixC empirical probabilities by mixed copula estimator of Laaha (2023b).